Developer Guides
=======================

Do you want to join the ProbNum development effort, but are unsure how? The developer guides below give step-by-step
instructions on how to contribute in different ways. All additions to ProbNum are made via a pull request to the
code repository on GitHub.

.. nbgallery::
   :maxdepth: 2

   creating_an_example_notebook
   adding_to_the_api_documentation
   implementing_a_probnum_method
   unit_testing
